/******************************************************************************/
/*
 * eRIC Example TimerA0 V1.1
 * Low Power Radio Solutions
 * March 2016
 * Built with CCS V6.1.2.00015
 * This example will demostrate how TimerA0 works. Both capture and compare functionalities are shown in this example
 * Pin19 is assigned to Compare1 and Pin16 is assigned to Capture2. 32768clock is chosen as TimerA0 clock source and mode chosen as UPmode where
 * timer counts from 0 - CC0(32768) continously.
 * CC0 is set to 32768. CC1 is set as 16384. So therefore it takes 1 sec for timercount to reach CC0(32768) from 0 with 32768clock as clocksource and
 * then restarts from 0 again. CC1 Interrupt flag is set when timercount value is equal to CC1(which is set to 16384).CC1 output mode is Set/reset so any pin(Pin19 in this example)
 * assigned to CC1 will set when timercount reaches CC1(16384) and resets when timercount reaches CC0(32768).
 * So Pin19 should set/reset every 500ms and Pin18 should toggle every 1 sec when CC1 interrupt flag is set.
 * when Pin16 is held high, CC2 capture flag is set and current timercount value is captured and is sent to uart to display.
 * If captured timercount is 16384 then TIMEREXAMPLE is sent through UART.
 *
 */

/******************************************************************************/
//Version V1.1
#include<cc430f5137.h>
#include "eRIC.h"
#include <stdio.h>
#include <string.h>

volatile const char Data[] = {'T','I','M','E','R',' ','E','X','A','M','P','L','E'};

int main(void)
{
	eRIC_WDT_Stop();                   //Stop watch dog timer, just in case
	eRIC_GlobalInterruptDisable();     //Global interrupts disabled

	eRIC_SetCpuFrequency(1000000);    //Sets CPU clock to 1mHz

	//TimerA0 is set with clock source of ACLK 32768 and Upmode(counts from 0-CC0)
	eRIC_TimerA0_Setup(eRICTimer_Cs_32k+eRICTimer_Div_1+eRICTimer_UpMode+eRICTimer_Reset);

	//Compare1 is set up with Outputmode set/reset where CC1 pin will set at CC1 value and resets at CC0 value.
	eRIC_TimerA0_Capture1orCompare1Setup(eRICTimer_CompareMode+eRICTimer_OutputMode_Set_Reset);

	eRIC_TimerA0_Capture0orCompare0_Data = 32768; //CC0 value
	eRIC_TimerA0_Capture1orCompare1_Data = 16384; //CC1 value


	Pin19_FunctionTA0CompareOut1();   //Pin19 is Assigned to CC1 compare
	Pin18_SetAsOutput();

	//Capture2 is set on rising edge and captures timer count value whenver CC2 pin is held low-high
	eRIC_TimerA0_Capture2orCompare2Setup(eRICTimer_CaptureOnRising+eRICTimer_CaptureMode);
	Pin16_FunctionTA0CaptureIn2(); //Pin16 Assigned to CC2 capture

	eRIC_UARTAInitialise(19200);   //Initialise Uart with 19200 baud to send captured value
	Pin3_FunctionUartATxOUT();

	eRIC_GlobalInterruptEnable();
	char i;
	while(1)
	{
		if(eRIC_TimerA0_Capture1orCompare1HasInterrupted())  //THis is set every 1 sec when CC1 value(16384) is equal to Timer count value
		{
			eRIC_TimerA0_Capture1orCompare1InterruptFlagClear(); //Clear flag
			Pin18_Toggle();
		}
		if(eRIC_TimerA0_Capture2orCompare2HasInterrupted())   //This is set when Pin16 is held low-high
		{
			eRIC_TimerA0_Capture2orCompare2InterruptFlagClear();
			eRIC_UartASendByte(eRIC_TimerA0_Capture2orCompare2_Data>>8);   //Capture2 high byte data is sent
			while(eRIC_UartATxBufferIsBusy());
			while(eRIC_UartABusy());
			eRIC_UartASendByte(eRIC_TimerA0_Capture2orCompare2_Data);      //Capture2 low byte data is sent
			while(eRIC_UartATxBufferIsBusy());
			while(eRIC_UartABusy());
			if(eRIC_TimerA0_Capture2orCompare2_Data==16384)  //This happens every second when Pin19 is connected to Pin16 and every 2 seconds if PIn18 is connected to Pin16
			{
			    i =0;
				while(i<13)
				{
				eRIC_UartASendByte(Data[i]);      //TIMEREXAMPLE word is sent
				while(eRIC_UartATxBufferIsBusy());
				while(eRIC_UartABusy());
				i++;
				}
			}

		}
	}//end of while(1)
}//end of main()


void eRIC_RfDataReceivedInterrupt()   // Add code here to deal with  available received data..THis is triggered when interrupt is enabled and a apcket is received
{
}
